Neural Pipeline based on PyTorch 0.4.1 and designed to standardize and facilitate the training process.

[![Build Status](https://travis-ci.org/toodef/neural-pipeline.svg?branch=master)](https://travis-ci.org/toodef/neural-pipeline) [![Coverage Status](https://coveralls.io/repos/github/toodef/neural-pipeline/badge.svg?branch=master)](https://coveralls.io/github/toodef/neural-pipeline?branch=master) [![PyPI version](https://badge.fury.io/py/neural-pipeline.svg)](https://badge.fury.io/py/neural-pipeline) 

It's contains:
* Checkpoints management and train process resuming
* Metrics processing and visualisation

# Installation:
`pip install neural-pipeline`



